package shopping;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import kam.util.ServletUtil;

public class ELShoppingServlet extends HttpServlet {

  private static final String shopPage = "/ELShop.jsp";
  private static final String cartPage = "/ELCart.jsp";
  private static final String checkOutPage = "/ELCheckout.jsp";
  private static final String errorPage = "/ELError.html";

  public void doPost(HttpServletRequest req, HttpServletResponse res)
      throws ServletException, IOException {
    HttpSession session = req.getSession(false);
    List<Item> buylist = null;
    if (session == null) {
      res.sendRedirect(shopPage);
    }
    System.out.println("session not null");
    buylist = (List) session.getAttribute("shoppingcart");
    System.out.println("buylist: " + (buylist == null));
    if (buylist == null) {
      buylist = new ArrayList<Item>();
      session.setAttribute("shoppingcart", buylist);
    }
    // Debugging
    ServletUtil.echoRequestParameters(req, new PrintWriter(System.out, true));
    ServletUtil.echoSessionInfo(session, new PrintWriter(System.out, true));

    String action = req.getParameter("action");
    System.out.println("Action: " + action);
    if (action.equals("DELETE")) {
      System.out.println("DELETE");
      String del = req.getParameter("delindex");
      int d = (new Integer(del)).intValue();
      buylist.remove(d);
      RequestDispatcher rd = req.getRequestDispatcher(cartPage);
      rd.forward(req, res);
    } else if (action.equals("ADD")) {
      System.out.println("ADD");
      Item anItem = getItem(req);
      if (buylist.contains(anItem)) {
        int i = buylist.indexOf(anItem);
        Item item = buylist.get(i);
        item.setQuantity(item.getQuantity() + anItem.getQuantity());
      } else {
        buylist.add(anItem);
      }
      RequestDispatcher rd = req.getRequestDispatcher(shopPage);
      rd.forward(req, res);
    } else if (action.equals("CHECKOUT")) {
      System.out.println("CHECKOUT");
      double total = 0;
      for (Item anOrder: buylist) {
        double price = anOrder.getPrice();
        int qty = anOrder.getQuantity();
        total += (price * qty);
      }
      String amount = String.format("%.2f", total);
      req.setAttribute("amount", amount);
      RequestDispatcher rd = req.getRequestDispatcher(checkOutPage);
      rd.forward(req, res);
    } else if (action.equals("SHOW")) {
      System.out.println("SHOW");
      String url = cartPage;
      RequestDispatcher rd = req.getRequestDispatcher(url);
      rd.forward(req, res);
    } else {
      System.out.println("ERROR");
      res.sendRedirect(errorPage);
    }
  }

  private Item getItem(HttpServletRequest req) {
    String myItem = req.getParameter("ITEM");
    String qty = req.getParameter("qty");
    StringTokenizer t = new StringTokenizer(myItem, "|");
    String itemName = t.nextToken();
    String itemDecsription = t.nextToken();
    String price = t.nextToken();
    price = price.replace('$', ' ').trim();
    Item item = new Item();
    item.setItemName(itemName);
    item.setItemDescription(itemDecsription);
    item.setPrice((new Double(price)).doubleValue());
    item.setQuantity((new Integer(qty)).intValue());
    return item;
  }
}

